
```

  ______ _______ __   _  _____   _____  __   __  _____  _______
 |  ____ |______ | \  | |     | |_____]   \_/   |_____] |______
 |_____| |______ |  \_| |_____| |          |    |       |______
                                                               
                                                

```
#### Description

`B i o i n f o r m a t i c s` pipelines require creating directories, checking intermediate files, checking if those intermediate files have anything in them, checking return/error codes, gzipping, deleting temporary files, converting sam to bam, etc.  `genopype` is a Python package I've developed for creating these bash pipelines quickly, in Python (v2.7+ & 3.5+), and easily.  Module previously known as `goomba`.

#### About

`__author__ = "Josh L. Espinoza"`

`__cite__ = "TBD"`

`__contact__ = "jespinoz@jcvi.org, jol.espinoz@gmail.com"`

`__developmental__ = True`

`__license__ = "BSD-3"`

`__version__ = "2020.03"`
